@@ -25,7 +25,7 @@
 #ifndef AKREGATOR_ACTIONMANAGER_H
 #define AKREGATOR_ACTIONMANAGER_H
 
-#include <qobject.h>
+#include <QObject>
 
 #include "akregator_export.h"
 
@@ -54,7 +54,7 @@ public:
     static void setInstance(ActionManager *manager);
 
     explicit ActionManager(QObject *parent = nullptr);
-    virtual ~ActionManager();
+    ~ActionManager() override;
 
     virtual QAction *action(const QString &name) = 0;
     virtual QWidget *container(const QString &name) = 0;
