@@ -33,8 +33,8 @@ class QObject;
 class QUrl;
 
 namespace Akregator {
-AKREGATOR_EXPORT QAction *createOpenLinkInNewTabAction(const QUrl &url, QObject *receiver = nullptr, const char *slot = nullptr, QObject *parent = nullptr);
-AKREGATOR_EXPORT QAction *createOpenLinkInExternalBrowserAction(const QUrl &url, QObject *receiver = nullptr, const char *slot = nullptr, QObject *parent = nullptr);
+AKREGATOR_EXPORT QAction *createOpenLinkInNewTabAction(const QUrl &url, QObject *parent = nullptr);
+AKREGATOR_EXPORT QAction *createOpenLinkInExternalBrowserAction(const QUrl &url, QObject *parent = nullptr);
 }
 
 #endif // AKREGATOR_ACTIONS_H
