@@ -23,11 +23,12 @@
 #include <KLocalizedString>
 #include <QVBoxLayout>
 #include <viewerplugintoolmanager.h>
-#include <KRun>
+#include <KIO/JobUiDelegate>
+#include <KIO/OpenUrlJob>
 
 #include <KPIMTextEdit/kpimtextedit/texttospeechwidget.h>
 
-#include <kpimtextedit/slidecontainer.h>
+#include <KPIMTextEdit/SlideContainer>
 
 #include <WebEngineViewer/FindBarWebEngineView>
 #include <WebEngineViewer/WebEngineExportHtmlPageJob>
@@ -183,9 +184,11 @@ void ArticleViewerWebEngineWidgetNg::slotOpenInBrowser()
         connect(job, &WebEngineViewer::WebEngineExportHtmlPageJob::success, this, &ArticleViewerWebEngineWidgetNg::slotExportHtmlPageSuccess);
         job->start();
     } else {
-        KRun::RunFlags flags;
-        flags |= KRun::RunExecutables;
-        KRun::runUrl(currentUrl, QStringLiteral("text/html"), this, flags);
+        KIO::OpenUrlJob *job = new KIO::OpenUrlJob(currentUrl, QStringLiteral("text/html"));
+        job->setUiDelegate(new KIO::JobUiDelegate(KJobUiDelegate::AutoHandlingEnabled, this));
+        job->setDeleteTemporaryFile(true);
+        job->setRunExecutables(true);
+        job->start();
     }
 }
 
@@ -196,8 +199,8 @@ void ArticleViewerWebEngineWidgetNg::slotExportHtmlPageFailed()
 
 void ArticleViewerWebEngineWidgetNg::slotExportHtmlPageSuccess(const QString &filename)
 {
-    const QUrl url(QUrl::fromLocalFile(filename));
-    KRun::RunFlags flags;
-    flags |= KRun::DeleteTemporaryFiles;
-    KRun::runUrl(url, QStringLiteral("text/html"), this, flags);
+    KIO::OpenUrlJob *job = new KIO::OpenUrlJob(QUrl::fromLocalFile(filename), QStringLiteral("text/html"));
+    job->setUiDelegate(new KIO::JobUiDelegate(KJobUiDelegate::AutoHandlingEnabled, this));
+    job->setDeleteTemporaryFile(true);
+    job->start();
 }
