@@ -42,18 +42,15 @@
 
 #include "akregator_debug.h"
 #include <QIcon>
-#include <QFileInfo>
-#include <QDir>
 
 #include <QUrl>
-#include <KRandom>
 
 #include <QDateTime>
 #include <QDomDocument>
 #include <QDomElement>
 #include <QHash>
 #include <QList>
-#include <QPixmap>
+#include <QRandomGenerator>
 #include <QTimer>
 
 #include <memory>
@@ -372,14 +369,22 @@ Feed::~Feed()
 
 void Feed::loadFavicon(const QString &url, bool downloadFavicon)
 {
-    Akregator::DownloadFeedIconJob *job = new Akregator::DownloadFeedIconJob(this);
-    job->setFeedIconUrl(url);
-    job->setDownloadFavicon(downloadFavicon);
-    connect(job, &DownloadFeedIconJob::result, this, [this](const QString &result) {
-        setFaviconUrl(result);
-    });
-    if (!job->start()) {
-        qCWarning(AKREGATOR_LOG) << "Impossible to start DownloadFeedIconJob for url: " << url;
+    QUrl u(url);
+    if (u.scheme().isEmpty()) {
+        qCWarning(AKREGATOR_LOG) << "Invalid url" << url;
+    }
+    if (u.isLocalFile()) {
+        setFaviconLocalPath(u.toLocalFile());
+    } else {
+        Akregator::DownloadFeedIconJob *job = new Akregator::DownloadFeedIconJob(this);
+        job->setFeedIconUrl(u);
+        job->setDownloadFavicon(downloadFavicon);
+        connect(job, &DownloadFeedIconJob::result, this, [this](const QString &fileName) {
+                setFaviconLocalPath(fileName);
+                });
+        if (!job->start()) {
+            qCWarning(AKREGATOR_LOG) << "Impossible to start DownloadFeedIconJob for url: " << url;
+        }
     }
 }
 
@@ -482,7 +487,7 @@ void Feed::setXmlUrl(const QString &s)
 {
     d->m_xmlUrl = s;
     if (!Settings::fetchOnStartup()) {
-        QTimer::singleShot(KRandom::random() % 4000, this, &Feed::slotAddFeedIconListener);    // TODO: let's give a gui some time to show up before starting the fetch when no fetch on startup is used. replace this with something proper later...
+        QTimer::singleShot(QRandomGenerator::global()->bounded(4000), this, &Feed::slotAddFeedIconListener);    // TODO: let's give a gui some time to show up before starting the fetch when no fetch on startup is used. replace this with something proper later...
     }
 }
 
@@ -501,16 +506,19 @@ Feed::ImageInfo Feed::faviconInfo() const
     return d->m_faviconInfo;
 }
 
-void Feed::setFaviconUrl(const QString &url)
+void Feed::setFaviconLocalPath(const QString &localPath)
 {
-    d->m_faviconInfo.imageUrl = url;
-    setFavicon(QIcon(d->m_faviconInfo.imageUrl));
+    d->m_faviconInfo.imageUrl = QUrl::fromLocalFile(localPath).toString();
+    setFavicon(QIcon(localPath));
 }
 
 void Feed::setFaviconInfo(const Feed::ImageInfo &info)
 {
     d->m_faviconInfo = info;
-    setFavicon(QIcon(info.imageUrl));
+    QUrl u(info.imageUrl);
+    if (u.isLocalFile()) {
+        setFavicon(QIcon(u.toLocalFile()));
+    }
 }
 
 QString Feed::description() const
