@@ -27,7 +27,6 @@
 #include "frame.h"
 #include "actionmanager.h"
 #include "openurlrequest.h"
-#include <KRun>
 #include <KMacroExpander>
 #include <KProcess>
 #include <KShell>
@@ -36,6 +35,8 @@
 #include <webengine/webengineframe.h>
 #include <QStringList>
 #include <QDesktopServices>
+#include <KIO/JobUiDelegate>
+#include <KIO/OpenUrlJob>
 
 using namespace Akregator;
 
@@ -240,8 +241,8 @@ void FrameManager::openInExternalBrowser(const OpenUrlRequest &request)
     if (request.args().mimeType().isEmpty()) {
         QDesktopServices::openUrl(url);
     } else {
-        KRun::RunFlags flag = {};
-        KRun::runUrl(url, request.args().mimeType(), nullptr /*window*/, flag);
+        KIO::OpenUrlJob *job = new KIO::OpenUrlJob(url, request.args().mimeType());
+        job->start();
     }
 }
 
