@@ -49,7 +49,7 @@ public:
     Backend::Storage *storage();
     void setStorage(Backend::Storage *storage);
 
-    QSharedPointer<FeedList> feedList() const;
+    Q_REQUIRED_RESULT QSharedPointer<FeedList> feedList() const;
     void setFeedList(const QSharedPointer<FeedList> &feedList);
 
     FetchQueue *fetchQueue() const;
