@@ -27,7 +27,9 @@
 #include "akregator_options.h"
 #include "akregator_debug.h"
 #include "akregratormigrateapplication.h"
-
+#ifdef WITH_KUSERFEEDBACK
+#include "userfeedback/akregatoruserfeedbackprovider.h"
+#endif
 #include <KontactInterface/PimUniqueApplication>
 
 #include <KCrash>
@@ -100,6 +102,14 @@ int main(int argc, char **argv)
     cmdArgs->process(args);
     about.processCommandLine(cmdArgs);
 
+#ifdef WITH_KUSERFEEDBACK
+    if(cmdArgs->isSet(QStringLiteral("feedback"))) {
+        Akregator::AkregatorUserFeedbackProvider *userFeedBack = new Akregator::AkregatorUserFeedbackProvider(nullptr);
+        QTextStream(stdout) << userFeedBack->describeDataSources() << '\n';
+        delete userFeedBack;
+        return 0;
+    }
+#endif
     if (!Akregator::Application::start(args)) {
         qCWarning(AKREGATOR_LOG) << "akregator is already running, exiting.";
         exit(0);
