@@ -25,7 +25,6 @@
 #include "tabwidget.h"
 
 #include <QStyle>
-#include <QApplication>
 #include <QIcon>
 #include <QHash>
 #include <QString>
@@ -37,9 +36,7 @@
 #include "akregator_debug.h"
 #include <QTabWidget>
 #include <QTabBar>
-#include <KRun>
 #include <KLocalizedString>
-#include <KToolInvocation>
 #include <kio/global.h>
 
 #include "actionmanager.h"
