@@ -19,7 +19,7 @@
 
 #include "urlhandlerwebengine.h"
 #include "akregator_debug.h"
-#include "Libkdepim/BroadcastStatus"
+#include <PimCommon/BroadcastStatus>
 #include "articleviewer-ng/webengine/articleviewerwebengine.h"
 #include <KLocalizedString>
 #include <QDesktopServices>
@@ -77,7 +77,7 @@ bool MailToURLHandlerWebEngine::handleContextMenuRequest(const QUrl &url, const
                 QClipboard *clip = QApplication::clipboard();
                 clip->setText(fullEmail, QClipboard::Clipboard);
                 clip->setText(fullEmail, QClipboard::Selection);
-                KPIM::BroadcastStatus::instance()->setStatusMsg(i18n("Address copied to clipboard."));
+                PimCommon::BroadcastStatus::instance()->setStatusMsg(i18n("Address copied to clipboard."));
             }
         }
         delete menu;
