@@ -28,8 +28,7 @@
 #include "article.h"
 #include "widgets/statussearchline.h"
 
-#include <kcombobox.h>
-#include <klineedit.h>
+#include <KLineEdit>
 #include <KLocalizedString>
 
 #include <QString>
